@@ -7,7 +7,6 @@ import typing
 import click
 
 import uvicorn
-from uvicorn._impl.asyncio import AsyncioServer, AsyncioServerState
 from uvicorn.config import (
     HTTP_PROTOCOLS,
     INTERFACES,
@@ -19,6 +18,7 @@ from uvicorn.config import (
     WS_PROTOCOLS,
     Config,
 )
+from uvicorn.server import Server, ServerState  # noqa: F401  # Used to be defined here.
 from uvicorn.supervisors import ChangeReload, Multiprocess
 
 LEVEL_CHOICES = click.Choice(LOG_LEVELS.keys())
@@ -30,10 +30,6 @@ INTERFACE_CHOICES = click.Choice(INTERFACES)
 
 logger = logging.getLogger("uvicorn.error")
 
-# Aliases for backwards compatibility. These used to be defined here.
-Server = AsyncioServer
-ServerState = AsyncioServerState
-
 
 def print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
@@ -142,7 +138,7 @@ def print_version(ctx, param, value):
     "--log-config",
     type=click.Path(exists=True),
     default=None,
-    help="Logging configuration file.",
+    help="Logging configuration file. Supported formats: .ini, .json, .yaml.",
     show_default=True,
 )
 @click.option(
@@ -277,6 +273,13 @@ def print_version(ctx, param, value):
     help="Look for APP in the specified directory, by adding this to the PYTHONPATH."
     " Defaults to the current working directory.",
 )
+@click.option(
+    "--factory",
+    is_flag=True,
+    default=False,
+    help="Treat APP as an application factory, i.e. a () -> <ASGI app> callable.",
+    show_default=True,
+)
 def main(
     app,
     host: str,
@@ -314,6 +317,7 @@ def main(
     headers: typing.List[str],
     use_colors: bool,
     app_dir: str,
+    factory: bool,
 ):
     sys.path.insert(0, app_dir)
 
@@ -353,6 +357,7 @@ def main(
         "ssl_ciphers": ssl_ciphers,
         "headers": list([header.split(":", 1) for header in headers]),
         "use_colors": use_colors,
+        "factory": factory,
     }
     run(**kwargs)
 
